@@ -17,8 +17,8 @@
 ## -*- texinfo -*-
 ## @deftypefn {Function File} {} vtk_close(@var{n})
 ## Closes the specified vtk figure window.  All structures referencing
-## the figure window must be cleared from userspace in order for the
-## window to close.
+## the figure window (perhaps 'ans') must be cleared from userspace
+## in order for the window to close.
 ## @end deftypefn
 ## @seealso{vtk_clear}
 
@@ -27,4 +27,3 @@
 function f = vtk_close( fig_no )
 	vtk_figure( -abs(fig_no) );
 endfunction
- 
\ No newline at end of file
