@@ -27,6 +27,7 @@ function vtk_update(f)
   
   f.outline_actor.VisibilityOff();
   f.axes.VisibilityOff();
+
   if ( f.axes_on )
     b = f.renderer.ComputeVisiblePropBounds();
     f.outline.SetBounds( b(1), b(2), b(3), b(4), b(5), b(6) );
@@ -39,3 +40,14 @@ function vtk_update(f)
   f.window.Render();
   
 endfunction
+
+## 'f.axes_on' is reverting to 1 after being set to 0, effectively making the if statement above of no effect
+## to be solved later; JJS 1/24/07
+## for example, do:
+##(make a figure with axes, e.g. vtk_sombsurf)
+##f = vtk_figure(0);
+##f.axes_on = 0
+##vtk_update (f);
+##clear f
+##f = vtk_figure (0);
+##f.axes_on
